/*
 * Generate a VGA signal using a PIC32 microcontroller.
 *
 * Copyright (C) 2017, 2018 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __VGA_H__
#define __VGA_H__

#define LINE_LENGTH             160 /* pixels */
#define LINE_COUNT              256 /* distinct display lines */
#define LINE_MULTIPLIER         2

/* 24MHz cycle measurements. */

#define HFREQ_LIMIT             643
#define HSYNC_START             460
#define HSYNC_LIMIT             64
#define HSYNC_END               (HSYNC_START + HSYNC_LIMIT)

/* Horizontal lines, back porch end. */

#define VISIBLE_START           70
#define VFP_START               (VISIBLE_START + LINE_MULTIPLIER * LINE_COUNT)

/* Horizontal lines, front porch end. */

#define VSYNC_START             620

/* Horizontal lines, back porch start. */

#define VSYNC_END               622

/* Framebuffer properties. */

#define SCREEN_SIZE             (LINE_LENGTH * LINE_COUNT)

/* Transfer and pixel allocation properties. */

#define TRANSFER_CELL_SIZE      (LINE_LENGTH / 2)
#define CELL_SIZE               4

#endif /* __VGA_H__ */
